Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Encode ¶
Encode encrypts and signs keystore using password and writes its representation into w It is strongly recommended to fill password slice with zero after usage
func EncodeWithRand ¶
Encode encrypts and signs keystore using password and writes its representation into w Random bytes are read from rand, which must be a cryptographically secure source of randomness It is strongly recommended to fill password slice with zero after usage
Types ¶
type Certificate ¶
Certificate describes type of certificate
type KeyStore ¶
type KeyStore map[string]interface{}
KeyStore is a mapping of alias to pointer to PrivateKeyEntry or TrustedCertificateEntry
type PrivateKeyEntry ¶
type PrivateKeyEntry struct {
Entry
PrivateKey []byte
CertificateChain []Certificate
}
PrivateKeyEntry is an entry for private keys and associated certificates
type TrustedCertificateEntry ¶
type TrustedCertificateEntry struct {
Entry
Certificate Certificate
}
TrustedCertificateEntry is an entry for certificates only